@@ -98,7 +98,7 @@ def create_transformation_dict(scales, levels):
     """
     Create a dictionary with the transformation information for 3D images.
 
-    :param scales: The scale of the image, in x y z order.
+    :param scales: The scale of the image, in z y x order.
     :param levels: The number of levels in the pyramid.
     :return:
     """
@@ -119,9 +119,9 @@ def generate_axes_dict():
     :return: The axes dictionary
     """
     axes = [
-        {"name": "x", "type": "space", "unit": "micrometer"},
+        {"name": "z", "type": "space", "unit": "micrometer"},
         {"name": "y", "type": "space", "unit": "micrometer"},
-        {"name": "z", "type": "space", "unit": "micrometer"}
+        {"name": "x", "type": "space", "unit": "micrometer"}
     ]
     return axes
 
@@ -187,10 +187,11 @@ def remove_stripe_based_wavelet_fft(image, level=5, sigma=1, order=8, pad=150):
     return image[:nrow, :ncol]
 
 
-def load_hdf5(hdf5_file, map_file="temp.dat"):
+def load_hdf5(hdf5_file, use_mem_map=True, map_file="temp.dat"):
     """
     Load a HDF5 into a numpy memmap.
     :param hdf5_file: The HDF5 file to load.
+    :param use_mem_map: Whether to use a memmap or not.
     :param map_file: The memmap file to save to.
     :return: The memmap.
     """
@@ -199,24 +200,29 @@ def load_hdf5(hdf5_file, map_file="temp.dat"):
         n_frames = len(keys)
         key_list = [base_key + "{:03d}".format(i + 1) for i in range(len(keys))]
         frame = file[key_list[0]][:]
-        data = np.memmap(map_file, dtype=np.uint16, mode='w+', shape=(frame.shape[0], frame.shape[1], n_frames))
+        if use_mem_map:
+            data = np.memmap(map_file, dtype=np.uint32, mode='w+', shape=(n_frames, frame.shape[0], frame.shape[1]))
+        else:
+            data = np.zeros((n_frames, frame.shape[0], frame.shape[1]), dtype=np.uint32)
         for i, key in enumerate(
                 tqdm.tqdm(key_list, desc="Loading HDF5 file..", unit="frames", total=len(key_list),
                           leave=False, position=1)):
             frame = file[key][:]
-            data[:, :, i] = frame
+            data[i, :, :] = frame
+
     return data
 
 
-def convert_hdf5_to_nifti(hdf5_file, nifti_file):
+def convert_hdf5_to_nifti(hdf5_file, nifti_file, use_mem_map=True):
     """
     Convert a HDF5 file from the lightsheet microscope to a NIFTI file.
     :param hdf5_file: Path to the HDF5 file.
     :param nifti_file: Path to the NIFTI file.
+    :param use_mem_map: Whether to use a memmap or not.
     :return:
     """
     map_file = "temp.dat"
-    data = load_hdf5(hdf5_file, map_file)
+    data = load_hdf5(hdf5_file, use_mem_map, map_file)
 
     print("Saving...")
     ni_img = nib.Nifti1Image(data, affine=np.eye(4), dtype=np.uint16)
@@ -231,7 +237,7 @@ def save_zarr(data, zarr_file, remove_stripes=False, scales=(6.5, 6.5, 6.5), chu
     :param data: The data to save.
     :param zarr_file: The zarr file to save to.
     :param remove_stripes: Whether to remove stripes from the data.
-    :param scales: The resolution of the image, in x y z order.
+    :param scales: The resolution of the image, in z y x order.
     :param chunks: The chunk size to use.
     :return:
     """
@@ -239,29 +245,32 @@ def save_zarr(data, zarr_file, remove_stripes=False, scales=(6.5, 6.5, 6.5), chu
         for i in tqdm.tqdm(range(data.shape[0]), desc="Removing stripes", leave=False, unit="frames",
                            total=data.shape[0], position=1):
             data[i, :, :] = remove_stripe_based_wavelet_fft(data[i, :, :])
-        print("Saving...")
-        os.mkdir(zarr_file)
-        store = parse_url(zarr_file, mode="w").store
-        root = zarr.group(store=store)
-        write_image(image=data, group=root, axes=generate_axes_dict(),
-                    coordinate_transformations=create_transformation_dict(scales, 5),
-                    storage_options=dict(chunks=chunks), scaler=CustomScaler(downscale=2, method="nearest"))
-        print("Done!")
+
+    print("Saving...")
+    os.mkdir(zarr_file)
+    store = parse_url(zarr_file, mode="w").store
+    root = zarr.group(store=store)
+    write_image(image=data, group=root, axes=generate_axes_dict(),
+                coordinate_transformations=create_transformation_dict(scales, 5),
+                storage_options=dict(chunks=chunks), scaler=CustomScaler(downscale=2, method="nearest"))
+    print("Done!")
 
 
-def convert_hdf5_to_zarr(hdf5_file, zarr_file, remove_stripes=False, scales=(6.5, 6.5, 6.5), chunks=(512, 512, 512)):
+def convert_hdf5_to_zarr(hdf5_file, zarr_file, use_mem_map=True, remove_stripes=False, scales=(6.5, 6.5, 6.5),
+                         chunks=(512, 512, 512)):
     """
     Convert a HDF5 file from the lightsheet microscope to a zarr file.
     :param hdf5_file: Path to the HDF5 file.
     :param zarr_file: Path to the zarr file.
+    :param use_mem_map: Whether to use a memmap or not.
     :param remove_stripes: Whether to remove stripes from the data.
-    :param scales: The resolution of the image, in x y z order.
+    :param scales: The resolution of the image, in z y x order.
     :param chunks: The chunk size to use.
     :return:
     """
 
     map_file = "temp.dat"
-    data = load_hdf5(hdf5_file, map_file)
+    data = load_hdf5(hdf5_file, use_mem_map, map_file)
 
     save_zarr(data, zarr_file, remove_stripes, scales=scales, chunks=chunks)
     os.remove(map_file)
@@ -272,7 +281,7 @@ def convert_nifti_to_zarr(nifti_file, zarr_file, scales=(6.5, 6.5, 6.5), chucks=
     Convert a NIFTI file to a zarr file.
     :param nifti_file: The NIFTI file to convert.
     :param zarr_file: The zarr file to save to.
-    :param scales: The resolution of the image, in z x y order.
+    :param scales: The resolution of the image, in z y x order.
     :param chucks: The chunk size to use in the zarr file.
 
     """
@@ -287,7 +296,7 @@ def convert_nrrd_to_zarr(nrrd_file, zarr_file, scales=(6.5, 6.5, 6.5), chucks=(5
     Convert a NRRD file to a zarr file.
     :param nrrd_file: The NRRD file to convert.
     :param zarr_file: The zarr file to save.
-    :param scales: The resolution of the image, in z x y order.
+    :param scales: The resolution of the image, in z y x order.
     :param chucks: The chunk size to use in the zarr file.
     """
     print("Loading...")
